==> haskell-entropy-0.3.7-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-entropy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: entropy
version: 0.3.7
id: entropy-0.3.7-GVoReSVE1cZ4Y1pKgzhBYO
key: entropy-0.3.7-GVoReSVE1cZ4Y1pKgzhBYO
license: BSD3
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: https://github.com/TomMD/entropy
synopsis: A platform independent entropy source
description:
    A platform independent method to obtain cryptographically strong entropy
    (RDRAND when available anywhere, urandom on nix, CryptAPI on Windows, patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.
category: Data, Cryptography
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
exposed: True
exposed-modules:
    System.Entropy
hidden-modules: System.EntropyNix
abi: 217e0880228282724d1419933c9e2f45
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/entropy-0.3.7
library-dirs: /usr/lib/ghc-8.0.2/site-local/entropy-0.3.7
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/entropy-0.3.7
hs-libraries: HSentropy-0.3.7-GVoReSVE1cZ4Y1pKgzhBYO
depends:
    base-4.9.1.0 bytestring-0.10.8.1 unix-2.7.2.1
haddock-interfaces: /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html: /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-entropy-0.3.8-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-entropy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: entropy
version: 0.3.8
id: entropy-0.3.8-14HIw40nRRY968j6AdY1H4
key: entropy-0.3.8-14HIw40nRRY968j6AdY1H4
license: BSD3
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: https://github.com/TomMD/entropy
synopsis: A platform independent entropy source
description:
    A platform independent method to obtain cryptographically strong entropy
    (RDRAND when available anywhere, urandom on nix, CryptAPI on Windows, patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.
category: Data, Cryptography
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
exposed: True
exposed-modules:
    System.Entropy
hidden-modules: System.EntropyNix
abi: d05ff3147f0152dbae9cfc934254fc26
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/entropy-0.3.8
library-dirs: /usr/lib/ghc-8.0.2/site-local/entropy-0.3.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/entropy-0.3.8
hs-libraries: HSentropy-0.3.8-14HIw40nRRY968j6AdY1H4
depends:
    base-4.9.1.0 bytestring-0.10.8.1 unix-2.7.2.1
haddock-interfaces: /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html: /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
